@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class dim20:
     stemlen = linespacing * 3.5
     xshift = 10
     col_width = 20
-    first_staff_ypos = 50
+    first_staff_ypos = 70
     staff_spacing = 70
     ledger_left = -4
     ledger_right = 14
@@ -143,7 +143,7 @@ class TieEngraver(Engraver):
         self.m_xpos2 += - 3 + self.m_shift2 * dim.xshift
         w = self.m_xpos2 - self.m_xpos1
         h = 8
-        widget.window.draw_arc(gc, gtk.FALSE,
+        widget.window.draw_arc(gc, False,
               self.m_xpos1, staff_yoffset + dim.linespacing*(self.m_ylinepos-1)/2 + 3,
               w, h, 64 * 180, 64*180)
 
@@ -223,9 +223,9 @@ class KeySignatureEngraver(Engraver):
             im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, type))
             im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
                     self.m_xpos + x,
-                    accidental_y_offset[type] + staff_yoffset
+                    int(accidental_y_offset[type] + staff_yoffset
                      + dimentions[self.m_fontsize].linespacing*ypos/2
-                     + accidental_y_offset[type], -1, -1,
+                     + accidental_y_offset[type]), -1, -1,
                      gtk.gdk.RGB_DITHER_NONE, 0, 0)
 
 
@@ -253,7 +253,7 @@ class NoteheadEngraver(Engraver):
         im.set_from_file(fetadir+'/feta%i-noteheads-%i.xpm' % (self.m_fontsize, self.m_head))
         im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
                     self.m_xpos + self.m_shift * dim.xshift,
-                    staff_yoffset + dim.linespacing*self.m_ypos/2 - 4,
+                    int(staff_yoffset + dim.linespacing*self.m_ypos/2 - 4),
                     -1, -1,
                      gtk.gdk.RGB_DITHER_NONE, 0, 0)
         im.set_from_file(fetadir+'/feta20-dots-dot.xpm')
