@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
                 self.m_height = d[3]
             #self.g_pixmap = pixmap = gtk.create_pixmap(self.g_d,
             #                         self.m_width, self.m_height)
-            darea.window.draw_rectangle(self.white_gc, gtk.TRUE, 0, 0,
+            darea.window.draw_rectangle(self.white_gc, True, 0, 0,
                                self.m_width, self.m_height)
             staff_centrum = dim.first_staff_ypos
             self.m_clickables = []
@@ -108,11 +108,6 @@ class MusicDisplayer(gtk.ScrolledWindow):
                     if isinstance(e, engravers.StemEngraver):
                         continue
                     e.engrave(darea, self.black_gc, staff_centrum)
-                    ####e.engrave(self.g_d, pixmap, self.black_gc, staff_centrum)
-                    #if isinstance(e, engravers.NoteheadEngraver):
-                    #    self.add_clickable_region(e.m_xpos + e.m_shift * dim.xshift,
-                    #                e.m_ypos*dim.linespacing/2+staff_centrum-4,
-                    #                10, 10, e.m_midi_int)
                 # stems has to be drawn after noteheads and accidentals
                 for e in staff:
                     if isinstance(e, engravers.StemEngraver):
