@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -211,6 +211,20 @@ instrument_names = (
     "applause", # 126
     "gunshot") # 127
 
+def find_midi_instrument_number(instr_name):
+    """
+    Try to find the integer representing the instrument instr_name.
+    Do a substring search if we don't get an exact match.
+    Raise KeyError if we don't find the instrument.
+    """
+    for i in range(len(instrument_names)):
+        if instr_name == instrument_names[i]:
+            return i
+    for i in range(len(instrument_names)):
+        if instrument_names[i].find(instr_name) != -1:
+            return i
+    raise KeyError(instr_name)
+
 # the names are taken directly from the OSS documentation (pdf file)
 percussion_names = [
         "Acoustic Bass Drum", # 35
