@@ -93,6 +93,7 @@ class SolfegeApp(cfg.ConfigUtils):
         self.m_teachers = {}
         self.m_running_exercise = None
         self.lessonfile_manager = lessonfile.LessonFileManager()
+        self.m_sound_init_exception = None
         self.setup_sound()
     def check_rcfile(self):
         """See default.config for rcfileversion values, meanings and
@@ -145,14 +146,7 @@ the preferences window.
                              cfg.get_string("sound/card_info"),
                              verbose_init='--verbose-sound-init' in self.m_argv)
             except (soundcard.SoundInitException, OSError), e:
-                if e == None:
-                    self.m_ui.display_error_message(
-"""You should configure sound
-from the 'Sound' page of
-the preferences window.
-""")
-                else:
-                    self.display_sound_init_error_message(e)
+                self.m_sound_init_exception = e
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
@@ -170,12 +164,13 @@ should try to quit that other program and restart Solfege."""
  % e)
         else:
             self.m_ui.display_error_message(
-"""The sound init failed: %s
-You should configure sound
-from the 'Sound' page of
-the preferences window.
+"""The sound init failed: 
+    %s
+You should configure sound from the 'Sound' page of the preferences window.
+
+It is also possible that the OS sound setup is incorrect.
 """
- % errno.errorcode[e.errno])
+ % (e))
     def play_happy_sound(self):
         mpd.play_music(r"\staff\relative c'{c16 e g a}", 180, 8,
                cfg.get_int('config/preferred_instrument_velocity'))
