@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,6 +59,20 @@ TODO:
 []
 >>> c.get_list("ss/a=[1, 2, 3]")
 [1, 2, 3]
+>>> comment_re.match("# basd") != None
+True
+>>> section_re.match("#[section]") == None
+True
+>>> section_re.match(" [section]") == None
+True
+>>> section_re.match("[section]") != None
+True
+>>> value_re.match("key=value") != None
+True
+>>> value_re.match("#key=value") == None
+True
+>>> value_re.match(" key=value") == None
+True
 """
 
 import string, re
@@ -70,8 +84,8 @@ if sys.platform == 'win32':
     if not os.path.exists(os.path.expanduser("~")):
         os.makedirs(os.path.expanduser("~"))
 
-section_re = re.compile("\[(.*?)\]")
-value_re = re.compile("(.*?)=(.*)")
+section_re = re.compile("^\[([\w-]*?)\]")
+value_re = re.compile(  "^([\w-]*?)=(.*)")
 comment_re = re.compile("#.*")
 
 # FIXME why did I comment out the lines below. Test in ms windows
@@ -90,7 +104,9 @@ def parse_file_into_dict(dict, filename):
         section_m = section_re.match(line)
         value_m = value_re.match(line)
         comment_m = comment_re.match(line)
-        if section_m:
+        if comment_m:
+            pass
+        elif section_m:
             section = section_m.groups()[0]
             if not dict.has_key(section):
                 dict[section] = {}
@@ -99,8 +115,6 @@ def parse_file_into_dict(dict, filename):
             dict[section][value_m.groups()[0]] = value_m.groups()[1]
         elif line == "\n":
             pass
-        elif comment_m:
-            pass
         else:
            print filename
            raise Exception("Shit happended line %s" % line)
@@ -123,39 +137,44 @@ def _maybe_create_key(key):
 ########################
 
 def set_string(key, val):
-    global data
+    global data, _watches, _blocked_watches
     _maybe_create_key(key)
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = val
     if _watches.has_key(key) and (oldval != get_string(key)):
+        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+            return
         for cb in _watches[key].values():
             cb(key)
 
 def set_int(key, val):
-    global data, _watches
+    global data, _watches, _blocked_watches
     assert type(val) == types.IntType
     _maybe_create_key(key)
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = str(val)
     if _watches.has_key(key) and (oldval != get_string(key)):
+        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+            return
         for cb in _watches[key].values():
             cb(key)
 
 def set_float(key, val):
-    global data, _watches
+    global data, _watches, _blocked_watches
     assert type(val) == types.FloatType
     _maybe_create_key(key)
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = str(val)
     if _watches.has_key(key) and (oldval != get_string(key)):
+        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+            return
         for cb in _watches[key].values():
             cb(key)
 
 def set_bool(key, val):
-    global data, _watches
     _maybe_create_key(key)
     if val:
         set_string(key, "true")
@@ -163,7 +182,6 @@ def set_bool(key, val):
         set_string(key, "false")
 
 def set_list(key, val):
-    global data, _watches
     set_string(key, str(val))
 
 ########################
@@ -206,6 +224,16 @@ def get_float(key):
    except KeyError:
        return float(default)
 
+def get_list(key):
+    if len(string.split(key, "=")) == 2:
+        key, default = string.split(key, "=")
+    else:
+        default = []
+    section, k = split(key)
+    try:
+        return eval(data[section][k])
+    except KeyError:
+        return default
 
 def get_bool(key):
     if get_string(key) == 'true':
@@ -216,8 +244,20 @@ def get_bool(key):
         print "warning: cfg.get_bool: value of '%s' is not true or false" % key
         return 0
 
-def get_list(key):
-    return eval(get_string(key))
+#####################################
+def del_key(key):
+    global data, _watches, _blocked_watches
+    section, k = split(key)
+    #FIXME watches
+    if not data.has_key(section):
+        print >> sys.stderr, "cfg.del_key: section does not exist"
+        return
+    if not data[section].has_key(k):
+        print >> sys.stderr, "cfg.del_key: section '%s' does not have key '%s'" % (section, k)
+        return
+    del data[section][k]
+    if not data[section]:
+        del data[section]
 
 ######################################
 ## reading and writing the database ##
@@ -237,16 +277,18 @@ def drop_user_config():
     Reread the config data, but only read the systems defaults, not
     .solfegerc in the users $HOME.
     """
-    global data, _watches, _watch_counter
+    global data, _watches, _watch_counter, _blocked_watches
     data = {}
     _watches = {}
     _watch_counter = 0
+    _blocked_watches = {}
     data = parse_file_into_dict(data, _system_filename)
 
 def reread_data():
-    global data, _watches, _watch_counter
+    global data, _watches, _watch_counter, _blocked_watches
     _watches = {}
     _watch_counter = 0
+    _blocked_watches = {}
     if _app_defaults_filename:
         data = parse_file_into_dict({}, _app_defaults_filename)
     if _system_filename:
@@ -260,10 +302,11 @@ def initialise(app_defaults_filename, system_filename, user_filename):
     system_filename: sys admin can override app_defaults_filename
     user_filename: the state of the app is stored here, also user config.
     """
-    global data, _watches, _watch_counter
+    global data, _watches, _watch_counter, _blocked_watches
     global _app_defaults_filename, _system_filename, _user_filename
     _watches = {}
     _watch_counter = 0
+    _blocked_watches = {}
     _app_defaults_filename = app_defaults_filename
     _system_filename = system_filename
     _user_filename = user_filename = os.path.expanduser(user_filename)
@@ -283,6 +326,22 @@ def initialise(app_defaults_filename, system_filename, user_filename):
 class ConfigUtils(object):
     def __init__(self, exname):
         self.m_exname = exname
+    def block_watch(self, name):
+        """
+        Stop functions watching a name being called. You have to call the
+        same number of unblock_watch calls as block_calls to remove a blocking.
+        """
+        global _blocked_watches
+        name = self._expand_name(name)
+        if not _blocked_watches.has_key(name):
+            _blocked_watches[name] = 0
+        _blocked_watches[name] += 1
+    def unblock_watch(self, name):
+        global _blocked_watches
+        name = self._expand_name(name)
+        assert _blocked_watches.has_key(name)
+        assert _blocked_watches[name] > 0
+        _blocked_watches[name] -= 1
     def add_watch(self, name, callback):
         global _watches, _watch_counter
         name = self._expand_name(name)
