@@ -16,6 +16,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk
+
+__exercise_data__ = {
+    'exercise_name': 'chord-voicing',
+    'menu_path': '%s/%s' % (_("_Chords"), _("_Chord voicing")),
+    'icon': 'graphics/chord24.png',
+    'toolbar': 1,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gnome
 
 import gu, widgets
@@ -32,9 +42,11 @@ import soundcard
 class Teacher(abstract.LessonbasedTeacher):
     OK = 0
     ERR_PICKY = 1
+    exercise_data = __exercise_data__
     #UGH should we do this here
-    def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        abstract.LessonbasedTeacher.__init__(self, exname, app,
+            lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.ChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -156,10 +168,8 @@ class Gui(abstract.LessonbasedGui):
         # config_box #
         ##############
         self.config_box.set_spacing(gnome.ui.PAD_SMALL)
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-            self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector)
+        self.add_select_lessonfile_gui()
+        self.add_random_transpose_gui()
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget=None):
         # if we have no lessonfile, then we have no questions.
@@ -193,6 +203,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_flashbar.flash(_("You have to solve this question first."))
     def update_gui_after_lessonfile_change(self, *v):
         if self.m_t.m_P:
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
             self.g_new.set_sensitive(True)
             self.fill_chordtype_box()
         else:
