@@ -21,7 +21,6 @@ import gtk, gnome, gnome.ui
 import gu, mpd
 import configureoutput
 import widgets
-from instrumentselector import ReadOnlyInstrumentSelector
 from instrumentselector import NewReadOnlyInstrumentSelector
 import cfg
 import app
@@ -245,7 +244,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
 
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
         self.g_wav_player = gtk.Combo()
-        print find_wav_player_programs()
         self.g_wav_player.set_popdown_strings(find_wav_player_programs())
         self.g_wav_player.entry.set_text(cfg.get_string('sound/wav_player'))
         self.g_wav_player.entry.connect('changed', self.on_changed)
