@@ -269,3 +269,24 @@ def hig_label_widget(txt, widget, sizegroup):
     label.set_use_underline(True)
     label.set_mnemonic_widget(widget[0])
     return hbox
+
+class SpinButtonRangeController(object):
+    def __init__(self, spin_low, spin_high, lowest_value, highest_value):
+        self.g_spin_low = spin_low
+        self.g_spin_low.connect('value-changed', self.on_low_changed)
+        self.g_spin_high = spin_high
+        self.g_spin_high.connect('value-changed', self.on_high_changed)
+        self.m_lowest_value = lowest_value
+        self.m_highest_value = highest_value
+    def on_low_changed(self, widget, *v):
+        if widget.get_value() > self.g_spin_high.get_value():
+            self.g_spin_low.set_value(self.g_spin_high.get_value())
+        elif widget.get_value() < self.m_lowest_value:
+            self.g_spin_low.set_value(self.m_lowest_value)
+    def on_high_changed(self, widget, *v):
+        if widget.get_value() < self.g_spin_low.get_value():
+            self.g_spin_high.set_value(self.g_spin_low.get_value())
+        elif widget.get_value() > self.m_highest_value:
+            self.g_spin_high.set_value(self.m_highest_value)
+
+
