@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -174,7 +174,7 @@ class IntervalPianoWidget(PianoKeyboard):
 
 class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
     def __init__(self, exname, name, callback, sensicallback, vars_to_watch):
-        gtk.Table.__init__(self, 1, 1, gtk.TRUE)
+        gtk.Table.__init__(self, 1, 1, True)
         cfg.ConfigUtils.__init__(self, exname)
         self.m_name = name
         self.get_sensitive_buttons = sensicallback
@@ -207,7 +207,7 @@ class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
             self.set_sensitivity(self.get_sensitive_buttons())
         else:
             for x in range(1, 17):
-                self.m_buttons[x].set_sensitive(gtk.TRUE)
+                self.m_buttons[x].set_sensitive(True)
     def set_sensitivity(self, make_active):
         for x in range(1, 17):
             self.m_buttons[x].set_sensitive(x in make_active)
