@@ -327,8 +327,8 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if not self.get_bool("gui/toolbar_visible"):
             self.get_dock_item_by_name('toolbar').hide()
         self.box_dict['docviewer'].grab_focus()
-        if not soundcard.synth:
-            self.display_error_message(_("Sound support is not configured yet. Select 'Preferences window' from the File menu, then select the page named 'Sound setup'."))
+        if self.m_app.m_sound_init_exception is not None:
+            self.m_app.display_sound_init_error_message(self.m_app.m_sound_init_exception)
     def activate_exercise(self, href):
         protocol, action, exname, anchor, collection, lessonfile, config = \
            utils.parse_url(href)
