@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'sing-interval',
+    'menu_path': '%s/%s' % (_("_Intervals"), _("_Sing interval")),
+    'icon': 'graphics/singinterval24.png',
+    'toolbar': 4,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import gu, widgets
 import soundcard, mpd, mpd.musicdisplayer
@@ -23,8 +32,9 @@ import statistics, statisticsviewer
 import utils
 
 class Teacher(abstract.MelodicIntervalTeacher):
-    def __init__(self, exname, app):
-        abstract.MelodicIntervalTeacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, config):
+        abstract.MelodicIntervalTeacher.__init__(self, exname, app, config)
         self._ignore_picky = 1
         self.m_statistics = statistics.IntervalStatistics(self)
     def get_question(self):
