@@ -3,15 +3,14 @@
 import pygtk
 pygtk.require("2.0")
 import sys, os
-if os.path.isdir("soundcard"):
+if __name__ == "__main__":
+    import sys
     sys.path.append(".")
-else:
-    sys.path.append("..")
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
 
 import src
-import gettext
-gettext.install('solfege', 'share/locale', unicode=1)
-import src.i18n
 
 
 import gnome.ui
@@ -33,7 +32,7 @@ class DisplaytestWindow(gtk.Window):
         self.g_text = gtk.TextView()
         self.g_text.set_size_request(-1, 100)
         self.g_text.show()
-        self.g_text.set_editable(gtk.TRUE)
+        self.g_text.set_editable(True)
         s = cfg.get_string('config/score_displayer')
         if not s:
             s = r"\staff{c' d' e'}"
@@ -52,31 +51,31 @@ class DisplaytestWindow(gtk.Window):
         gu.bButton(vbox, "Play first", self.on_play_first)
     def on_parse(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         score = mpd.parser.parse_to_score_object(t)
     def on_display(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20)
     def on_display_first_notes(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20, mpd.FIRST)
     def on_display_last_notes(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20, mpd.LAST)
     def on_play(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         cfg.set_string('config/score_displayer', t)
         mpd.play_music(t, (120, 4), 0, 100)
     def on_play_first(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), gtk.TRUE)
+                                self.m_buf.get_end_iter(), True)
         tr = mpd.music_to_track(t, 100, soundcard.rat.Rat(0, 1), soundcard.rat.Rat(1, 8))
         soundcard.synth.play_track(tr)
 
